==> office-ui-fabric-vue-7.0.26.tgz: package/lib/components/Label/Label.base.js <==
import '../node_modules/core-js/modules/es.date.to-string.js';
import '../node_modules/core-js/modules/es.object.to-string.js';
import '../node_modules/core-js/modules/es.reflect.construct.js';
import '../node_modules/core-js/modules/es.regexp.to-string.js';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import StatelessComponent from '../StatelessComponent.js';
import _mergeJSXProps from '../node_modules/@vue/babel-helper-vue-jsx-merge-props/dist/helper.js';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction({
  disableCaching: true
});

var LabelBase = function (_StatelessComponent) {
  _inherits(LabelBase, _StatelessComponent);

  var _super = _createSuper(LabelBase);

  function LabelBase() {
    _classCallCheck(this, LabelBase);

    return _super.apply(this, arguments);
  }

  _createClass(LabelBase, [{
    key: "render",
    value: function render(h, context) {
      var _context$props = context.props,
          theme = _context$props.theme,
          className = _context$props.className,
          disabled = _context$props.disabled,
          required = _context$props.required;
      var classNames = getClassNames(context.props.styles, {
        className: className,
        disabled: disabled,
        required: required,
        theme: theme
      });
      return h("label", _mergeJSXProps([{
        "class": classNames.root
      }, context.data]), [context.children]);
    }
  }]);

  return LabelBase;
}(StatelessComponent);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], LabelBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  "default": false
}), __metadata("design:type", Boolean)], LabelBase.prototype, "required", void 0);

LabelBase = __decorate([Component], LabelBase);

export { LabelBase };

==> office-ui-fabric-vue-7.0.27.tgz: package/lib/components/Label/Label.base.js <==
import 'core-js/modules/es.object.to-string';
import 'core-js/modules/es.reflect.construct';
import 'core-js/modules/es.regexp.to-string';
import _classCallCheck from '@babel/runtime/helpers/classCallCheck';
import _createClass from '@babel/runtime/helpers/createClass';
import _inherits from '@babel/runtime/helpers/inherits';
import _possibleConstructorReturn from '@babel/runtime/helpers/possibleConstructorReturn';
import _getPrototypeOf from '@babel/runtime/helpers/getPrototypeOf';
import { __decorate, __metadata } from 'tslib';
import { Prop, Component } from 'vue-property-decorator';
import { classNamesFunction } from '@uifabric-vue/utilities';
import StatelessComponent from '../StatelessComponent.js';
import _mergeJSXProps from '@vue/babel-helper-vue-jsx-merge-props';

function _createSuper(Derived) { var hasNativeReflectConstruct = _isNativeReflectConstruct(); return function _createSuperInternal() { var Super = _getPrototypeOf(Derived), result; if (hasNativeReflectConstruct) { var NewTarget = _getPrototypeOf(this).constructor; result = Reflect.construct(Super, arguments, NewTarget); } else { result = Super.apply(this, arguments); } return _possibleConstructorReturn(this, result); }; }

function _isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }
var getClassNames = classNamesFunction({
  disableCaching: true
});

var LabelBase = function (_StatelessComponent) {
  _inherits(LabelBase, _StatelessComponent);

  var _super = _createSuper(LabelBase);

  function LabelBase() {
    _classCallCheck(this, LabelBase);

    return _super.apply(this, arguments);
  }

  _createClass(LabelBase, [{
    key: "render",
    value: function render(h, context) {
      var _context$props = context.props,
          theme = _context$props.theme,
          className = _context$props.className,
          disabled = _context$props.disabled,
          required = _context$props.required;
      var classNames = getClassNames(context.props.styles, {
        className: className,
        disabled: disabled,
        required: required,
        theme: theme
      });
      return h("label", _mergeJSXProps([{
        "class": classNames.root
      }, context.data]), [context.children]);
    }
  }]);

  return LabelBase;
}(StatelessComponent);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], LabelBase.prototype, "disabled", void 0);

__decorate([Prop({
  type: Boolean,
  default: false
}), __metadata("design:type", Boolean)], LabelBase.prototype, "required", void 0);

LabelBase = __decorate([Component], LabelBase);

export { LabelBase };
